@@ -180,7 +180,7 @@ def title_icon_admin():
 @register.simple_tag()
 def url_account():
     try:
-        _namespace_url = 'admin:' + re.sub('\.', '_', settings.TESTE.lower()) + '_change'
+        _namespace_url = 'admin:' + re.sub('\.', '_', settings.AUTH_USER_MODEL.lower()) + '_change'
     except:
         _namespace_url = 'admin:auth_user_change'
 
